netapp_ontap.models.volume_rebalancing1_engine_scanner_blocks_skipped API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_rebalancing1_engine_scanner_blocks_skipped`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeRebalancing1EngineScannerBlocksSkippedSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeRebalancing1EngineScannerBlocksSkipped object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `efficiency_blocks: Size GET`

    Number of blocks skipped by the scanner on this constituent because storage efficiency lost, in blocks, would be too high.

  `efficiency_percent: Size GET`

    Number of blocks skipped by the scanner on this constituent because storage efficiency lost, in percent, would be too high.

  `fast_truncate: Size GET`

    Number of blocks skipped by the scanner on this constituent because fast truncate is currently running on files.

  `footprint_invalid: Size GET`

    Number of blocks skipped by the scanner on this constituent because of files with invalid space footprints.

  `in_snapshot: Size GET`

    Number of blocks skipped by the scanner on this constituent because of files in snapshots.

  `incompatible: Size GET`

    Number of blocks skipped by the scanner on this constituent because of incompatible files.

  `metadata: Size GET`

    Number of blocks skipped by the scanner on this constituent because of metadata files.

  `on_demand_destination: Size GET`

    Number of blocks skipped by the scanner on this constituent because of on demand destination files.

  `other: Size GET`

    Number of blocks skipped by the scanner on this constituent for all other reasons.

  `remote_cache: Size GET`

    Number of blocks skipped by the scanner on this constituent because of remote caches.

  `too_large: Size GET`

    Number of blocks skipped by the scanner on this constituent because of files that are larger than rebalancing.max_file_size.

  `too_small: Size GET`

    Number of blocks skipped by the scanner on this constituent because of files that are smaller than rebalancing.min_file_size.

  `write_fenced: Size GET`

    Number of blocks skipped by the scanner on this constituent because of files fenced for write operations.